#!/usr/local/bin/lua
local function radius(x, y)
	return math.sqrt(x * x + y * y)
end
local function pythagorean(a, b)
	return radius(a.x - b.x, a.y - b.y)
end

local function processInput(...)
	local sessions = {}
	local position = {}
	local tiltBegan
	local touch
	for line in ... do
		local action, phase
		action, phase, line = line:match('([&!%%])(.)(.*)')
		if action == '%' then
			local x, y, z = line:match('%((%-?[%d.]+),%s*(%-?[%d.]+),%s*(%-?[%d.]+)%)')
			if x then
				z = math.abs(z)
				local angles = {x = math.atan2(x, z) / math.pi + 0, y = math.atan2(y, z) / math.pi + 0}--.1666}
				if angles.x > 1 then angles.x = angles.x - 2 end
				if angles.y > 1 then angles.y = angles.y - 2 end
				if radius(angles.x, angles.y) > 0.075 then
					tiltBegan = true
				else
					tiltBegan = nil
				end
			end
		elseif action == '&' then
			local x, y = line:match('%((%-?[%d.]+),%s*%-?[%d.]+,%s*(%-?[%d.]+)%)')
			if touch then
				touch.length = touch.length + radius((x or 0) - (position.x or 0), (y or 0) - (position.y or 0))
			end
			position.x, position.y = x, y
			if not tiltBegan then
				if touch and touch.complete then
					table.insert(sessions, touch.length)
					touch = nil
				end
			end
		elseif action == '!' then
			local button = line:match('^%d')
			if phase == '^' then
				if touch and touch.length then
					table.insert(sessions, touch.length)
				end
				touch = {length = 0}
			elseif phase == '$' then
				if touch then touch.complete = true end
			end
		end
	end
	return sessions
end

local function outputCSV(file, t)
	local ID = file:match("([^/.]+).log")
	for _, value in ipairs(t) do
		io.write(ID, ',', value, '\n')
	end
end

local function outputAverage(file, t)
	print(file)
	local total = 0
	for _, distance in ipairs(t) do
		total = total + distance
	end
	print("Average Length Swiped:", total / #t)
end

require "parse_files" (processInput, outputCSV, ...)
