#!/usr/local/bin/lua
local function radius(x, y)
	return math.sqrt(x * x + y * y)
end
local function pythagorean(a, b)
	return radius(a.x - b.x, a.y - b.y)
end

local function processInput(...)
	local sessions = {}
	local position = {}
	local tiltBegan
	for line in ... do
		local action
		action, line = line:match('([&%%])%=(.*)')
		if action == '%' then
			local x, y, z = line:match('%((%-?[%d.]+),%s*(%-?[%d.]+),%s*(%-?[%d.]+)%)')
			if x then
				z = math.abs(z)
				local angles = {x = math.atan2(x, z) / math.pi + 0, y = math.atan2(y, z) / math.pi + 0.1666}
				if angles.x > 1 then angles.x = angles.x - 2 end
				if angles.y > 1 then angles.y = angles.y - 2 end
				if radius(angles.x, angles.y) > 0.075 then
					if not tiltBegan then
						tiltBegan = {x = tonumber(position.x) or 0, y = tonumber(position.y) or 0}
					end
				else
					if tiltBegan then
						position.x, position.y = tonumber(position.x) or 0, tonumber(position.y) or 0
						local travel = pythagorean(position, tiltBegan)
						if travel ~= 0 then table.insert(sessions, travel) end
						tiltBegan = nil
					end
				end
			end
		elseif action == '&' then
			position.x, position.y = line:match('%((%-?[%d.]+),%s*%-?[%d.]+,%s*(%-?[%d.]+)%)')
		end
	end
	return sessions
end

local function outputCSV(file, t)
	local ID = file:match("([^/.]+).log")
	for _, value in ipairs(t) do
		io.write(ID, ',', value, '\n')
	end
end

local function outputAverage(file, t)
	print(file)
	local total = 0
	for _, distance in ipairs(t) do
		total = total + distance
	end
	print("Average Distance Tilted:", total / #t)
end

require "parse_files" (processInput, outputCSV, ...)
