#!/usr/local/bin/lua
local function radius(x, y)
	return math.sqrt(x * x + y * y)
end
local function pythagorean(a, b)
	return radius(a.x - b.x, a.y - b.y)
end

local function processInput(...)
	local sessions = {}
	local position = {}
	local tiltlength
	for line in ... do
		local action
		action, line = line:match('([&%%])%=(.*)')
		if action == '%' then
			local x, y, z = line:match('%((%-?[%d.]+),%s*(%-?[%d.]+),%s*(%-?[%d.]+)%)')
			if x then
				z = math.abs(z)
				local angles = {x = math.atan2(x, z) / math.pi + 0, y = math.atan2(y, z) / math.pi + 0.1666}
				if angles.x > 1 then angles.x = angles.x - 2 end
				if angles.y > 1 then angles.y = angles.y - 2 end
				if radius(angles.x, angles.y) > 0.075 then
					if not tiltLength then
						tiltLength = 0
					end
				else
					if tiltLength then
						if tiltLength ~= 0 then table.insert(sessions, tiltLength) end
						tiltLength = nil
					end
				end
			end
		elseif action == '&' then
			local x, y = line:match('%((%-?[%d.]+),%s*%-?[%d.]+,%s*(%-?[%d.]+)%)')
			if tiltLength then
				tiltLength = tiltLength + radius((x or 0) - (position.x or 0), (y or 0) - (position.y or 0))
			end
			position.x, position.y = x, y
		end
	end
	return sessions
end

local function outputCSV(file, t)
	local ID = file:match("([^/.]+).log")
	for _, value in ipairs(t) do
		io.write(ID, ',', value, '\n')
	end
end

local function outputAverage(file, t)
	print(file)
	local total = 0
	for _, distance in ipairs(t) do
		total = total + distance
	end
	print("Average Length Tilted:", total / #t)
end

require "parse_files" (processInput, outputCSV, ...)
