#!/usr/local/bin/lua
local function radius(x, y)
	return math.sqrt(x * x + y * y)
end
local function pythagorean(a, b)
	return radius(a.x - b.x, a.y - b.y)
end

local function processInput(...)
	local sessions = {}
	local open = {}
	local first
	for line in ... do
		local timestamp, phase
		timestamp, phase, line = line:match('([%d_]+)%= %!(.)(.*)')
		if timestamp then
			local tt = {}
			tt.year, tt.month, tt.day, tt.hour, tt.min, tt.sec = timestamp:match("(%d%d%d%d)(%d%d)(%d%d)_(%d%d)(%d%d)(%d%d)")
			first = first or os.time(tt)
			local button
			if phase == '^' then
				button = line:sub(1, 1)
				open[button] = true
			elseif phase == '$' then
				button = line:sub(1, 1)
				open[button] = nil
			end
			if button then
				local count = 0
				for button, value in pairs(open) do
					if value then count = count + 1 end
				end
				table.insert(sessions, {time = os.difftime(os.time(tt), first), count = count, button=button})
			end
		end
	end
	return sessions
end

local function outputCSV(file, t)
	local ID = file:match("([^/.]+).log")
	for _, value in ipairs(t) do
		io.write(ID, ',', value.time, ',', value.count, ',', value.button, '\n')
	end
end

local function outputAverage(file, t)
	print(file)
	local total = 0
	for _, distance in ipairs(t) do
		total = total + distance
	end
	print("Average Menu Suspension Time:", total / #t)
end

require "parse_files" (processInput, outputCSV, ...)
